#include <stdio.h>
#include <stdlib.h>

#include "apr_general.h"
#include "apr_pools.h"
#include "apr_memcache.h"
#include "apr_hash.h"

int main(int argc, char **argv)
{
    apr_status_t rv;
    apr_pool_t *p;
    apr_memcache_t *memc;
    apr_memcache_server_t *ms;
    apr_hash_t *values;

    char *keys[]= {"foo", "bar", "baz"};
    unsigned int num_of_keys = 3;
    int i;

    apr_initialize();
    apr_pool_create(&p, NULL);
    rv = apr_memcache_create(p, 10, 0, &memc);
    if((rv = apr_memcache_server_create(p, "127.0.0.1", 11211, 0, 0, 0, 0, &ms)) != APR_SUCCESS) {
        fprintf(stderr, "could not connect to server.");
        return -1;
    }
    apr_memcache_add_server(memc, ms);

    values = apr_hash_make(p);
    for(i = 0; i < num_of_keys; i++) {
        apr_memcache_add_multget_key(p, keys[i], &values);
    }

    if(apr_memcache_multgetp(memc, p, p, values) == APR_SUCCESS) {
        apr_hash_index_t *hash_index;
        hash_index = apr_hash_first(p, values);
        while(hash_index) {
            void *v;
            apr_memcache_value_t* value;
            apr_hash_this(hash_index, NULL, NULL, &v);
            value = (apr_memcache_value_t *)v;
            if(value->status != APR_NOTFOUND)
                printf("%s\n", value->data);
            hash_index = apr_hash_next(hash_index);
        }
    }

    apr_pool_destroy(p);
    apr_terminate();

    return 0;

}
